Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(60)

Unified Diff: third_party/WebKit/Source/core/html/HTMLPlugInElement.h

Issue 2759063002: Remove most of Widget (FrameViewBase) class from HTMLPlugInElement. (Closed)
Patch Set: Fix shouldAccelerate Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/html/HTMLPlugInElement.h
diff --git a/third_party/WebKit/Source/core/html/HTMLPlugInElement.h b/third_party/WebKit/Source/core/html/HTMLPlugInElement.h
index 532340b3fecf33056b7f8bb7ff05de4cd3233f09..7840ace642fded995f3f75cb31762f6a471f0fb6 100644
--- a/third_party/WebKit/Source/core/html/HTMLPlugInElement.h
+++ b/third_party/WebKit/Source/core/html/HTMLPlugInElement.h
@@ -31,10 +31,10 @@
namespace blink {
-class FrameViewBase;
class HTMLImageLoader;
class LayoutPart;
class LayoutEmbeddedItem;
+class PluginView;
enum PreferPlugInsForImagesOption {
ShouldPreferPlugInsForImages,
@@ -157,7 +157,10 @@ class CORE_EXPORT HTMLPlugInElement : public HTMLFrameOwnerElement {
bool allowedToLoadObject(const KURL&, const String& mimeType);
bool wouldLoadAsNetscapePlugin(const String& url, const String& serviceType);
- void setPersistedPluginWidget(FrameViewBase*);
+ void setPlugin(PluginView*);
+ PluginView* releasePlugin();
+ PluginView* ownedPlugin() const;
+ void setPersistedPlugin(PluginView*);
bool requestObjectInternal(const String& url,
const String& mimeType,
@@ -172,12 +175,12 @@ class CORE_EXPORT HTMLPlugInElement : public HTMLFrameOwnerElement {
// avoid accessing |layoutObject()| in layoutObjectIsFocusable().
bool m_pluginIsAvailable = false;
- // Normally the Widget is stored in HTMLFrameOwnerElement::m_widget.
+ // Normally the plugin is stored in HTMLFrameOwnerElement::m_widget.
// However, plugins can persist even when not rendered. In order to
// prevent confusing code which may assume that widget() != null
// means the frame is active, we save off m_widget here while
// the plugin is persisting but not being displayed.
- Member<FrameViewBase> m_persistedPluginWidget;
+ Member<PluginView> m_persistedPlugin;
};
inline bool isHTMLPlugInElement(const HTMLElement& element) {
« no previous file with comments | « third_party/WebKit/Source/core/frame/LocalFrameClient.h ('k') | third_party/WebKit/Source/core/html/HTMLPlugInElement.cpp » ('j') | no next file with comments »
@@ -172,12 +175,12 @@ class CORE_EXPORT HTMLPlugInElement : public HTMLFrameOwnerElement {
// However, plugins can persist even when not rendered. In order to
- // prevent confusing code which may assume that widget() != null
+ // prevent confusing code which may assume that ownedWidget() != null
// means the frame is active, we save off m_widget here while
// the plugin is persisting but not being displayed.

Powered by Google App Engine
This is Rietveld 408576698